UI/SplashScreen.py

changeset 15
f6ccc31d6e72
parent 13
1af94a91f439
child 791
9ec2ac20e54e
diff -r 092aa8fafa4e -r f6ccc31d6e72 UI/SplashScreen.py
--- a/UI/SplashScreen.py	Sat Jan 02 16:15:57 2010 +0000
+++ b/UI/SplashScreen.py	Sat Jan 02 17:09:08 2010 +0000
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a splashscreen for eric4.
+Module implementing a splashscreen for eric5.
 """
 
 import os.path
@@ -13,11 +13,11 @@
 from PyQt4.QtCore import Qt
 from PyQt4.QtGui import QApplication, QPixmap, QSplashScreen, QColor
 
-from eric4config import getConfig
+from eric5config import getConfig
 
 class SplashScreen(QSplashScreen):
     """
     Class implementing a splashscreen for eric4.
     """
     def __init__(self):
         """
@@ -49,7 +49,7 @@
 
 class NoneSplashScreen(object):
     """
-    Class implementing a "None" splashscreen for eric4.
+    Class implementing a "None" splashscreen for eric5.
     
     This class implements the same interface as the real splashscreen,
     but simply does nothing.
@@ -80,4 +80,4 @@
         
         @param widget widget to wait for (QWidget)
         """
-        pass
+        pass
\ No newline at end of file
@@ -13,11 +13,11 @@
 class SplashScreen(QSplashScreen):
     """
-    Class implementing a splashscreen for eric4.
+    Class implementing a splashscreen for eric5.
     """
     def __init__(self):

eric ide

mercurial